==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/src/look_pk.cpp <==
/*************************************************
* PK Algorithm Lookup Source File                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/look_pk.h>
#include <opencl/lookup.h>

namespace OpenCL {

/*************************************************
* Get a PK_Encryptor object                      *
*************************************************/
PK_Encryptor* get_pk_encryptor(const PK_Encrypting_Key& key,
                               const std::string& eme)
   {
   if(eme == "Raw")
      return new PK_Encryptor(key);
   else
      return new PK_Encryptor(key, get_eme(eme));
   }

/*************************************************
* Get a PK_Decryptor object                      *
*************************************************/
PK_Decryptor* get_pk_decryptor(const PK_Decrypting_Key& key,
                               const std::string& eme)
   {
   if(eme == "Raw")
      return new PK_Decryptor(key);
   else
      return new PK_Decryptor(key, get_eme(eme));
   }

/*************************************************
* Get a PK_Signer object                         *
*************************************************/
PK_Signer* get_pk_signer(const PK_Signing_Key& key,
                         const std::string& encoding)
   {
   return new PK_Signer(key, get_emsa(encoding));
   }

/*************************************************
* Get a PK_Verifier object                       *
*************************************************/
PK_Verifier* get_pk_verifier(const PK_Verifying_with_MR_Key& key,
                             const std::string& encoding)
   {
   return new PK_Verifier_with_MR(key, get_emsa(encoding));
   }

/*************************************************
* Get a PK_Verifier object                       *
*************************************************/
PK_Verifier* get_pk_verifier(const PK_Verifying_wo_MR_Key& key,
                             const std::string& encoding)
   {
   return new PK_Verifier_wo_MR(key, get_emsa(encoding));
   }

/*************************************************
* Get a PK_Key_Agreement_Scheme object           *
*************************************************/
PK_Key_Agreement_Scheme* get_pk_kas(const PK_Key_Agreement_Key& key,
                                    const std::string& kdf)
   {
   if(kdf == "Raw")
      return new PK_Key_Agreement_Scheme(key);
   else
      return new PK_Key_Agreement_Scheme(key, get_kdf(kdf));
   }

}

==> OpenCL-0.9.0.tgz: OpenCL-0.9.0/src/look_pk.cpp <==
/*************************************************
* PK Algorithm Lookup Source File                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/look_pk.h>
#include <opencl/lookup.h>

namespace OpenCL {

/*************************************************
* Get a PK_Encryptor object                      *
*************************************************/
PK_Encryptor* get_pk_encryptor(const PK_Encrypting_Key& key,
                               const std::string& eme)
   {
   return new PK_Encryptor(key, eme);
   }

/*************************************************
* Get a PK_Decryptor object                      *
*************************************************/
PK_Decryptor* get_pk_decryptor(const PK_Decrypting_Key& key,
                               const std::string& eme)
   {
   return new PK_Decryptor(key, eme);
   }

/*************************************************
* Get a PK_Signer object                         *
*************************************************/
PK_Signer* get_pk_signer(const PK_Signing_Key& key,
                         const std::string& encoding)
   {
   return new PK_Signer(key, encoding);
   }

/*************************************************
* Get a PK_Verifier object                       *
*************************************************/
PK_Verifier* get_pk_verifier(const PK_Verifying_with_MR_Key& key,
                             const std::string& encoding)
   {
   return new PK_Verifier_with_MR(key, encoding);
   }

/*************************************************
* Get a PK_Verifier object                       *
*************************************************/
PK_Verifier* get_pk_verifier(const PK_Verifying_wo_MR_Key& key,
                             const std::string& encoding)
   {
   return new PK_Verifier_wo_MR(key, encoding);
   }

/*************************************************
* Get a PK_Key_Agreement_Scheme object           *
*************************************************/
PK_Key_Agreement_Scheme* get_pk_kas(const PK_Key_Agreement_Key& key,
                                    const std::string& kdf)
   {
   return new PK_Key_Agreement_Scheme(key, kdf);
   }

}
